--- myst: html_meta: title: AutoRAG - Available List description: All nodes and modules of AutoRAG keywords: AutoRAG,RAG,Advanced RAG,modules,nodes --- # Available List 📌 You can check our all supporting Nodes & modules

Nodes | Modules | YAML module names
1️⃣ Query Expansion | Query Decompose, HyDE, Multi Query Expansion, 📌 Pass Module: pass_query_expansion | query_decompose, hyde, multi_query_expansion, pass_query_expansion
2️⃣ Retrieval | BM25, VectorDB, 📌 Hybrid Module: hybrid_rrf, hybrid_cc | bm25, vectordb, hybrid_rrf, hybrid_cc
3️⃣ Passage Augmenter | Prev Next Augmenter, 📌 Pass Module: pass_passage_augmenter | prev_next_augmenter, pass_passage_augmenter
4️⃣ Passage Reranker | UPR, Tart, MonoT5, Cohere reranker, RankGPT, Jina Reranker, Sentence Transformer Reranker, Colbert Reranker, Flag Embedding Reranker, Flag Embedding LLM Reranker, Time Reranker, Ko-reranker, 📌 Pass Module: pass_reranker | upr, tart, monot5, cohere_reranker, rankgpt, jina_reranker, sentence_transformer_reranker, colbert_reranker, flag_embedding_reranker, flag_embedding_llm_reranker, time_reranker, ko_reranker, pass_reranker
5️⃣ Passage Filter | similarity threshold cutoff, similarity percentile cutoff, recency filter, 📌 Pass Module: pass_passage_filter | similarity_threshold_cutoff, similarity_percentile_cutoff, recency_filter, pass_passage_filter
6️⃣ Passage Compressor | Tree Summarize, Refine, 📌 Pass Module: pass_compressor | tree_summarize, refine, pass_compressor
7️⃣ Prompt Maker | Default Prompt Maker (f-string), Long Context Reorder, Window Replacement | fstring, long_context_reorder, window_replacement
8️⃣ Generator | llama index llm, openai_llm, vllm | llama_index_llm, openai_llm, vllm

For a comprehensive and up-to-date list of supporting nodes and modules, please refer to our dedicated Notion page. You can access this information [here](https://edai.notion.site/Supporting-Nodes-modules-0ebc7810649f4e41aead472a92976be4?pvs=4).